summaryrefslogtreecommitdiffstats
path: root/kate/app
diff options
context:
space:
mode:
Diffstat (limited to 'kate/app')
-rw-r--r--kate/app/kateapp.cpp4
-rw-r--r--kate/app/kateappIface.cpp2
-rw-r--r--kate/app/kateconfigdialog.cpp2
-rw-r--r--kate/app/kateconsole.cpp6
-rw-r--r--kate/app/katedocmanager.cpp8
-rw-r--r--kate/app/katedocmanager.h2
-rw-r--r--kate/app/kateexternaltools.cpp26
-rw-r--r--kate/app/kateexternaltools.h2
-rw-r--r--kate/app/katefilelist.cpp18
-rw-r--r--kate/app/katefilelist.h2
-rw-r--r--kate/app/katefileselector.cpp18
-rw-r--r--kate/app/katefileselector.h2
-rw-r--r--kate/app/kategrepdialog.cpp58
-rw-r--r--kate/app/katemailfilesdialog.cpp6
-rw-r--r--kate/app/katemain.cpp2
-rw-r--r--kate/app/katemainwindow.cpp12
-rw-r--r--kate/app/katemainwindow.h2
-rw-r--r--kate/app/katemdi.cpp14
-rw-r--r--kate/app/katemdi.h2
-rw-r--r--kate/app/katemwmodonhddialog.cpp4
-rw-r--r--kate/app/katemwmodonhddialog.h2
-rw-r--r--kate/app/katesession.cpp2
-rw-r--r--kate/app/katetabwidget.cpp6
-rw-r--r--kate/app/kateviewmanager.cpp2
-rw-r--r--kate/app/kateviewspace.cpp24
-rw-r--r--kate/app/kateviewspace.h4
-rw-r--r--kate/app/kateviewspacecontainer.cpp38
-rw-r--r--kate/app/kwritemain.cpp12
-rw-r--r--kate/app/kwritemain.h4
29 files changed, 143 insertions, 143 deletions
diff --git a/kate/app/kateapp.cpp b/kate/app/kateapp.cpp
index 70c81d465..084b6f313 100644
--- a/kate/app/kateapp.cpp
+++ b/kate/app/kateapp.cpp
@@ -127,7 +127,7 @@ Kate::Application *KateApp::application ()
/**
* Has always been the Kate Versioning Scheme:
- * KDE X.Y.Z contains Kate X-1.Y.Z
+ * KDE X.Y.Z tqcontains Kate X-1.Y.Z
*/
TQString KateApp::kateVersion (bool fullVersion)
{
@@ -396,4 +396,4 @@ KateMainWindow *KateApp::mainWindow (uint n)
return 0;
}
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/kateappIface.cpp b/kate/app/kateappIface.cpp
index 259e48b89..eb8b58a4f 100644
--- a/kate/app/kateappIface.cpp
+++ b/kate/app/kateappIface.cpp
@@ -101,4 +101,4 @@ const TQString & KateAppDCOPIface::session() const
return m_app->sessionManager()->activeSession()->sessionName();
}
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/kateconfigdialog.cpp b/kate/app/kateconfigdialog.cpp
index 47a7de19c..370abe97e 100644
--- a/kate/app/kateconfigdialog.cpp
+++ b/kate/app/kateconfigdialog.cpp
@@ -334,7 +334,7 @@ void KateConfigDialog::removePluginPage (Kate::Plugin *plugin)
{
if ( pluginPages.at(i)->plugin == plugin )
{
- TQWidget *w = pluginPages.at(i)->page->parentWidget();
+ TQWidget *w = pluginPages.at(i)->page->tqparentWidget();
delete pluginPages.at(i)->page;
delete w;
pluginPages.remove(pluginPages.at(i));
diff --git a/kate/app/kateconsole.cpp b/kate/app/kateconsole.cpp
index a160162db..b599ab202 100644
--- a/kate/app/kateconsole.cpp
+++ b/kate/app/kateconsole.cpp
@@ -57,8 +57,8 @@ void KateConsole::loadConsoleIfNeeded()
{
if (m_part) return;
- if (!topLevelWidget() || !parentWidget()) return;
- if (!topLevelWidget() || !isVisibleTo(topLevelWidget())) return;
+ if (!tqtopLevelWidget() || !tqparentWidget()) return;
+ if (!tqtopLevelWidget() || !isVisibleTo(tqtopLevelWidget())) return;
KLibFactory *factory = KLibLoader::self()->factory("libkonsolepart");
@@ -86,7 +86,7 @@ void KateConsole::slotDestroyed ()
m_part = 0;
// hide the dockwidget
- if (parentWidget())
+ if (tqparentWidget())
{
m_mw->hideToolView (m_toolView);
m_mw->centralWidget()->setFocus ();
diff --git a/kate/app/katedocmanager.cpp b/kate/app/katedocmanager.cpp
index f60c09783..a8a13ab98 100644
--- a/kate/app/katedocmanager.cpp
+++ b/kate/app/katedocmanager.cpp
@@ -86,7 +86,7 @@ KateDocManager::~KateDocManager ()
{
m_metaInfos->setGroup(*it);
TQDateTime last = m_metaInfos->readDateTimeEntry("Time", def);
- if (last.daysTo(TQDateTime::currentDateTime()) > m_daysMetaInfos)
+ if (last.daysTo(TQDateTime::tqcurrentDateTime()) > m_daysMetaInfos)
m_metaInfos->deleteGroup(*it);
}
delete def;
@@ -306,7 +306,7 @@ bool KateDocManager::closeDocument(class Kate::Document *doc,bool closeURL)
KateApp::self()->mainWindow(i)->viewManager()->closeViews(documentNumber);
}
- if ( closeURL && m_tempFiles.contains( documentNumber ) )
+ if ( closeURL && m_tempFiles.tqcontains( documentNumber ) )
{
TQFileInfo fi( m_tempFiles[ documentNumber ].first.path() );
if ( fi.lastModified() <= m_tempFiles[ documentNumber ].second /*||
@@ -583,7 +583,7 @@ void KateDocManager::saveMetaInfos(Kate::Document *doc)
m_metaInfos->setGroup(doc->url().prettyURL());
doc->writeSessionConfig(m_metaInfos);
m_metaInfos->writeEntry("MD5", (const char *)md5);
- m_metaInfos->writeEntry("Time", TQDateTime::currentDateTime());
+ m_metaInfos->writeEntry("Time", TQDateTime::tqcurrentDateTime());
m_metaInfos->sync();
}
}
@@ -608,4 +608,4 @@ bool KateDocManager::computeUrlMD5(const KURL &url, TQCString &result)
return true;
}
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/katedocmanager.h b/kate/app/katedocmanager.h
index b35d0a65f..56f006ea8 100644
--- a/kate/app/katedocmanager.h
+++ b/kate/app/katedocmanager.h
@@ -154,4 +154,4 @@ class KateDocManager : public QObject
};
#endif
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/kateexternaltools.cpp b/kate/app/kateexternaltools.cpp
index 6680e26a4..a3482f2b5 100644
--- a/kate/app/kateexternaltools.cpp
+++ b/kate/app/kateexternaltools.cpp
@@ -127,7 +127,7 @@ bool KateExternalTool::checkExec()
bool KateExternalTool::valid( const TQString &mt ) const
{
- return mimetypes.isEmpty() || mimetypes.contains( mt );
+ return mimetypes.isEmpty() || mimetypes.tqcontains( mt );
}
//END KateExternalTool
@@ -191,7 +191,7 @@ bool KateExternalToolsCommand::exec (Kate::View *view, const TQString &cmd, TQSt
// kdDebug(13001)<<"KateExternalToolsCommand::exec: Could not get view widget"<<endl;
return false;
}
- KateMDI::MainWindow *dmw=dynamic_cast<KateMDI::MainWindow*>(wv->topLevelWidget());
+ KateMDI::MainWindow *dmw=dynamic_cast<KateMDI::MainWindow*>(wv->tqtopLevelWidget());
if (!dmw) {
// kdDebug(13001)<<"KateExternalToolsCommand::exec: Could not get main window"<<endl;
return false;
@@ -330,8 +330,8 @@ void KateExternalToolsMenuAction::reload()
bool sepadded = false;
for (TQStringList::iterator itg = dtools.begin(); itg != dtools.end(); ++itg )
{
- if ( ! tools.contains( *itg ) &&
- ! removed.contains( *itg ) )
+ if ( ! tools.tqcontains( *itg ) &&
+ ! removed.tqcontains( *itg ) )
{
if ( ! sepadded )
{
@@ -394,7 +394,7 @@ void KateExternalToolsMenuAction::slotDocumentChanged()
if ( action )
{
l = action->tool->mimetypes;
- b = ( ! l.count() || l.contains( mt ) );
+ b = ( ! l.count() || l.tqcontains( mt ) );
action->setEnabled( b );
}
}
@@ -439,7 +439,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
leName = new TQLineEdit( w );
lo->addWidget( leName, 1, 2 );
l = new TQLabel( leName, i18n("&Label:"), w );
- l->setAlignment( l->alignment()|Qt::AlignRight );
+ l->tqsetAlignment( l->tqalignment()|Qt::AlignRight );
lo->addWidget( l, 1, 1 );
if ( tool ) leName->setText( tool->name );
TQWhatsThis::add( leName, i18n(
@@ -454,7 +454,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
teCommand = new TQTextEdit( w );
lo->addMultiCellWidget( teCommand, 2, 2, 2, 3 );
l = new TQLabel( teCommand, i18n("S&cript:"), w );
- l->setAlignment( Qt::AlignTop|Qt::AlignRight );
+ l->tqsetAlignment( Qt::AlignTop|Qt::AlignRight );
lo->addWidget( l, 2, 1 );
if ( tool ) teCommand->setText( tool->command );
TQWhatsThis::add( teCommand, i18n(
@@ -477,7 +477,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
leExecutable = new TQLineEdit( w );
lo->addMultiCellWidget( leExecutable, 3, 3, 2, 3 );
l = new TQLabel( leExecutable, i18n("&Executable:"), w );
- l->setAlignment( l->alignment()|Qt::AlignRight );
+ l->tqsetAlignment( l->tqalignment()|Qt::AlignRight );
lo->addWidget( l, 3, 1 );
if ( tool ) leExecutable->setText( tool->tryexec );
TQWhatsThis::add( leExecutable, i18n(
@@ -488,7 +488,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
leMimetypes = new TQLineEdit( w );
lo->addWidget( leMimetypes, 4, 2 );
l = new TQLabel( leMimetypes, i18n("&Mime types:"), w );
- l->setAlignment( l->alignment()|Qt::AlignRight );
+ l->tqsetAlignment( l->tqalignment()|Qt::AlignRight );
lo->addWidget( l, 4, 1 );
if ( tool ) leMimetypes->setText( tool->mimetypes.join("; ") );
TQWhatsThis::add( leMimetypes, i18n(
@@ -506,7 +506,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
cmbSave = new TQComboBox(w);
lo->addMultiCellWidget( cmbSave, 5, 5, 2, 3 );
l = new TQLabel( cmbSave, i18n("&Save:"), w );
- l->setAlignment( l->alignment()|Qt::AlignRight );
+ l->tqsetAlignment( l->tqalignment()|Qt::AlignRight );
lo->addWidget( l, 5, 1 );
TQStringList sl;
sl << i18n("None") << i18n("Current Document") << i18n("All Documents");
@@ -521,7 +521,7 @@ KateExternalToolServiceEditor::KateExternalToolServiceEditor( KateExternalTool *
leCmdLine = new TQLineEdit( w );
lo->addMultiCellWidget( leCmdLine, 6, 6, 2, 3 );
l = new TQLabel( leCmdLine, i18n("&Command line name:"), w );
- l->setAlignment( l->alignment()|Qt::AlignRight );
+ l->tqsetAlignment( l->tqalignment()|Qt::AlignRight );
lo->addWidget( l, 6, 1 );
if ( tool ) leCmdLine->setText( tool->cmdname );
TQWhatsThis::add( leCmdLine, i18n(
@@ -745,7 +745,7 @@ void KateExternalToolsConfigWidget::slotNew()
// This is sticky, it does not change again, so that shortcuts sticks
// TODO check for dups
- t->acname = "externaltool_" + TQString(t->name).replace( TQRegExp("\\W+"), "" );
+ t->acname = "externaltool_" + TQString(t->name).tqreplace( TQRegExp("\\W+"), "" );
new ToolItem ( lbTools, t->icon.isEmpty() ? blankIcon() : SmallIcon( t->icon ), t );
@@ -870,4 +870,4 @@ void KateExternalToolsConfigWidget::slotMoveDown()
m_changed = true;
}
//END KateExternalToolsConfigWidget
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/kateexternaltools.h b/kate/app/kateexternaltools.h
index 507e1cfca..71cc5eaf0 100644
--- a/kate/app/kateexternaltools.h
+++ b/kate/app/kateexternaltools.h
@@ -76,7 +76,7 @@ class KateExternalToolsMenuAction : public KActionMenu
};
/**
- * This Action contains a KateExternalTool
+ * This Action tqcontains a KateExternalTool
*/
class KateExternalToolAction : public KAction, public KWordMacroExpander
{
diff --git a/kate/app/katefilelist.h b/kate/app/katefilelist.h
index e90281558..837761780 100644
--- a/kate/app/katefilelist.h
+++ b/kate/app/katefilelist.h
@@ -188,4 +188,4 @@ class KFLConfigPage : public Kate::ConfigPage {
#endif
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/katefileselector.cpp b/kate/app/katefileselector.cpp
index 5ab42a289..789b6f735 100644
--- a/kate/app/katefileselector.cpp
+++ b/kate/app/katefileselector.cpp
@@ -96,7 +96,7 @@ void KateFileSelectorToolBarParent::resizeEvent ( TQResizeEvent * )
{
if (m_tb)
{
- setMinimumHeight(m_tb->sizeHint().height());
+ setMinimumHeight(m_tb->tqsizeHint().height());
m_tb->resize(width(),height());
}
}
@@ -113,17 +113,17 @@ KateFileSelector::KateFileSelector( KateMainWindow *mainWindow,
{
mActionCollection = new KActionCollection( this );
- QtMsgHandler oldHandler = qInstallMsgHandler( silenceQToolBar );
+ QtMsgHandler oldHandler = tqInstallMsgHandler( silenceQToolBar );
KateFileSelectorToolBarParent *tbp=new KateFileSelectorToolBarParent(this);
toolbar = new KateFileSelectorToolBar(tbp);
tbp->setToolBar(toolbar);
toolbar->setMovingEnabled(false);
toolbar->setFlat(true);
- qInstallMsgHandler( oldHandler );
+ tqInstallMsgHandler( oldHandler );
cmbPath = new KURLComboBox( KURLComboBox::Directories, true, this, "path combo" );
- cmbPath->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
+ cmbPath->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
KURLCompletion* cmpl = new KURLCompletion(KURLCompletion::DirCompletion);
cmbPath->setCompletionObject( cmpl );
cmbPath->setAutoDeleteCompletionObject( true );
@@ -157,7 +157,7 @@ KateFileSelector::KateFileSelector( KateMainWindow *mainWindow,
btnFilter->setIconSet( SmallIconSet("filter" ) );
btnFilter->setToggleButton( true );
filter = new KHistoryCombo( true, filterBox, "filter");
- filter->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
+ filter->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Fixed ));
filterBox->setStretchFactor(filter, 2);
connect( btnFilter, TQT_SIGNAL( clicked() ), this, TQT_SLOT( btnFilterClick() ) );
@@ -354,7 +354,7 @@ void KateFileSelector::setDir( KURL u )
newurl.setPath(pathstr);
if ( !kateFileSelectorIsReadable ( newurl ) )
- newurl.cd(TQString::fromLatin1(".."));
+ newurl.cd(TQString::tqfromLatin1(".."));
if ( !kateFileSelectorIsReadable (newurl) )
newurl.setPath( TQDir::homeDirPath() );
@@ -692,13 +692,13 @@ void KFSConfigPage::init()
KAction *ac;
TQListBox *lb;
for ( TQStringList::Iterator it=allActions.begin(); it != allActions.end(); ++it ) {
- lb = l.contains( *it ) ? acSel->selectedListBox() : acSel->availableListBox();
+ lb = l.tqcontains( *it ) ? acSel->selectedListBox() : acSel->availableListBox();
if ( *it == "bookmarks" || *it == "sync_dir" )
ac = fileSelector->actionCollection()->action( (*it).latin1() );
else
ac = fileSelector->dirOperator()->actionCollection()->action( (*it).latin1() );
if ( ac )
- new ActionLBItem( lb, SmallIcon( ac->icon() ), ac->text().replace( re, "" ), *it );
+ new ActionLBItem( lb, SmallIcon( ac->icon() ), ac->text().tqreplace( re, "" ), *it );
}
// sync
@@ -719,4 +719,4 @@ void KFSConfigPage::slotMyChanged()
slotChanged();
}
//END KFSConfigPage
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/katefileselector.h b/kate/app/katefileselector.h
index 442d3101e..4a52a6ea1 100644
--- a/kate/app/katefileselector.h
+++ b/kate/app/katefileselector.h
@@ -169,4 +169,4 @@ class KFSConfigPage : public Kate::ConfigPage {
#endif //__KATE_FILESELECTOR_H__
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/kategrepdialog.cpp b/kate/app/kategrepdialog.cpp
index 409bfd0a1..99d0b7501 100644
--- a/kate/app/kategrepdialog.cpp
+++ b/kate/app/kategrepdialog.cpp
@@ -85,22 +85,22 @@ GrepTool::GrepTool(TQWidget *parent, const char *name)
<< "*";
}
- TQGridLayout *layout = new TQGridLayout(this, 6, 3, 4, 4);
- layout->setColStretch(0, 10);
- layout->addColSpacing(1, 10);
- layout->setColStretch(1, 0);
- layout->setColStretch(2, 1);
- layout->setRowStretch(1, 0);
- layout->setRowStretch(2, 10);
- layout->setRowStretch(4, 0);
+ TQGridLayout *tqlayout = new TQGridLayout(this, 6, 3, 4, 4);
+ tqlayout->setColStretch(0, 10);
+ tqlayout->addColSpacing(1, 10);
+ tqlayout->setColStretch(1, 0);
+ tqlayout->setColStretch(2, 1);
+ tqlayout->setRowStretch(1, 0);
+ tqlayout->setRowStretch(2, 10);
+ tqlayout->setRowStretch(4, 0);
TQGridLayout *loInput = new TQGridLayout(4, 2, 4);
- layout->addLayout(loInput, 0, 0);
+ tqlayout->addLayout(loInput, 0, 0);
loInput->setColStretch(0, 0);
loInput->setColStretch(1, 20);
TQLabel *lPattern = new TQLabel(i18n("Pattern:"), this);
- lPattern->setFixedSize(lPattern->sizeHint());
+ lPattern->setFixedSize(lPattern->tqsizeHint());
loInput->addWidget(lPattern, 0, 0, AlignRight | AlignVCenter);
TQBoxLayout *loPattern = new TQHBoxLayout( 4 );
@@ -112,22 +112,22 @@ GrepTool::GrepTool(TQWidget *parent, const char *name)
cmbPattern->setInsertionPolicy(TQComboBox::NoInsertion);
lPattern->setBuddy(cmbPattern);
cmbPattern->setFocus();
- cmbPattern->setMinimumSize(cmbPattern->sizeHint());
+ cmbPattern->setMinimumSize(cmbPattern->tqsizeHint());
loPattern->addWidget( cmbPattern );
cbCasesensitive = new TQCheckBox(i18n("Case sensitive"), this);
- cbCasesensitive->setMinimumWidth(cbCasesensitive->sizeHint().width());
+ cbCasesensitive->setMinimumWidth(cbCasesensitive->tqsizeHint().width());
cbCasesensitive->setChecked(config->readBoolEntry("CaseSensitive", true));
loPattern->addWidget(cbCasesensitive);
cbRegex = new TQCheckBox( i18n("Regular expression"), this );
- cbRegex->setMinimumWidth( cbRegex->sizeHint().width() );
+ cbRegex->setMinimumWidth( cbRegex->tqsizeHint().width() );
cbRegex->setChecked( config->readBoolEntry( "Regex", true ) );
loPattern->addWidget( cbRegex );
loPattern->setStretchFactor( cmbPattern, 100 );
TQLabel *lTemplate = new TQLabel(i18n("Template:"), this);
- lTemplate->setFixedSize(lTemplate->sizeHint());
+ lTemplate->setFixedSize(lTemplate->tqsizeHint());
loInput->addWidget(lTemplate, 1, 0, AlignRight | AlignVCenter);
TQBoxLayout *loTemplate = new TQHBoxLayout(4);
@@ -136,7 +136,7 @@ GrepTool::GrepTool(TQWidget *parent, const char *name)
leTemplate = new KLineEdit(this);
lTemplate->setBuddy(leTemplate);
leTemplate->setText(strTemplate[0]);
- leTemplate->setMinimumSize(leTemplate->sizeHint());
+ leTemplate->setMinimumSize(leTemplate->tqsizeHint());
loTemplate->addWidget(leTemplate);
KComboBox *cmbTemplate = new KComboBox(false, this);
@@ -146,19 +146,19 @@ GrepTool::GrepTool(TQWidget *parent, const char *name)
loTemplate->addWidget(cmbTemplate);
TQLabel *lFiles = new TQLabel(i18n("Files:"), this);
- lFiles->setFixedSize(lFiles->sizeHint());
+ lFiles->setFixedSize(lFiles->tqsizeHint());
loInput->addWidget(lFiles, 2, 0, AlignRight | AlignVCenter);
cmbFiles = new KComboBox(true, this);
lFiles->setBuddy(cmbFiles->focusProxy());
- cmbFiles->setMinimumSize(cmbFiles->sizeHint());
+ cmbFiles->setMinimumSize(cmbFiles->tqsizeHint());
cmbFiles->setInsertionPolicy(TQComboBox::NoInsertion);
cmbFiles->setDuplicatesEnabled(false);
cmbFiles->insertStringList(lastSearchFiles);
loInput->addWidget(cmbFiles, 2, 1);
TQLabel *lDir = new TQLabel(i18n("Folder:"), this);
- lDir->setFixedSize(lDir->sizeHint());
+ lDir->setFixedSize(lDir->tqsizeHint());
loInput->addWidget(lDir, 3, 0, AlignRight | AlignVCenter);
TQBoxLayout *loDir = new TQHBoxLayout(3);
@@ -176,24 +176,24 @@ GrepTool::GrepTool(TQWidget *parent, const char *name)
lDir->setBuddy(cmbDir);
cbRecursive = new TQCheckBox(i18n("Recursive"), this);
- cbRecursive->setMinimumWidth(cbRecursive->sizeHint().width());
+ cbRecursive->setMinimumWidth(cbRecursive->tqsizeHint().width());
cbRecursive->setChecked(config->readBoolEntry("Recursive", true));
loDir->addWidget(cbRecursive);
KButtonBox *actionbox = new KButtonBox(this, Qt::Vertical);
- layout->addWidget(actionbox, 0, 2);
+ tqlayout->addWidget(actionbox, 0, 2);
actionbox->addStretch();
btnSearch = static_cast<KPushButton*>(actionbox->addButton(KGuiItem(i18n("Find"),"find")));
btnSearch->setDefault(true);
btnClear = static_cast<KPushButton*>(actionbox->addButton( KStdGuiItem::clear() ));
actionbox->addStretch();
- actionbox->layout();
+ actionbox->tqlayout();
lbResult = new TQListBox(this);
TQFontMetrics rb_fm(lbResult->fontMetrics());
- layout->addMultiCellWidget(lbResult, 2, 2, 0, 2);
+ tqlayout->addMultiCellWidget(lbResult, 2, 2, 0, 2);
- layout->activate();
+ tqlayout->activate();
KAcceleratorManager::manage( this );
@@ -225,11 +225,11 @@ GrepTool::GrepTool(TQWidget *parent, const char *name)
"You may give several patterns separated by commas."));
TQWhatsThis::add(lTemplate,
i18n("You can choose a template for the pattern from the combo box\n"
- "and edit it here. The string %s in the template is replaced\n"
+ "and edit it here. The string %s in the template is tqreplaced\n"
"by the pattern input field, resulting in the regular expression\n"
"to search for."));
TQWhatsThis::add(lDir,
- i18n("Enter the folder which contains the files in which you want to search."));
+ i18n("Enter the folder which tqcontains the files in which you want to search."));
TQWhatsThis::add(cbRecursive,
i18n("Check this box to search in all subfolders."));
TQWhatsThis::add(cbCasesensitive,
@@ -329,7 +329,7 @@ void GrepTool::slotSearch()
return;
}
- if ( ! leTemplate->text().contains("%s") )
+ if ( ! leTemplate->text().tqcontains("%s") )
{
leTemplate->setFocus();
return;
@@ -347,9 +347,9 @@ void GrepTool::slotSearch()
TQString s = cmbPattern->currentText();
if ( ! cbRegex->isChecked() )
- s.replace( TQRegExp( "([^\\w'()<>])" ), "\\\\1" );
+ s.tqreplace( TQRegExp( "([^\\w'()<>])" ), "\\\\1" );
TQString pattern = leTemplate->text();
- pattern.replace( "%s", s );
+ pattern.tqreplace( "%s", s );
childproc = new KProcess();
childproc->setWorkingDirectory( m_workingDir );
@@ -476,7 +476,7 @@ void GrepTool::childExited()
if ( ! errbuf.isEmpty() )
{
- KMessageBox::information( parentWidget(), i18n("<strong>Error:</strong><p>") + errbuf, i18n("Grep Tool Error") );
+ KMessageBox::information( tqparentWidget(), i18n("<strong>Error:</strong><p>") + errbuf, i18n("Grep Tool Error") );
errbuf.truncate(0);
}
else
diff --git a/kate/app/katemailfilesdialog.cpp b/kate/app/katemailfilesdialog.cpp
index 79a1e19c6..52bf1f243 100644
--- a/kate/app/katemailfilesdialog.cpp
+++ b/kate/app/katemailfilesdialog.cpp
@@ -78,7 +78,7 @@ KateMailDialog::KateMailDialog( TQWidget *parent, KateMainWindow *mainwin )
}
list->hide();
connect( this, TQT_SIGNAL(user1Clicked()), this, TQT_SLOT(slotShowButton()) );
- mw->setMinimumSize( lInfo->sizeHint() );
+ mw->setMinimumSize( lInfo->tqsizeHint() );
}
TQPtrList<Kate::Document> KateMailDialog::selectedDocs()
@@ -105,8 +105,8 @@ void KateMailDialog::slotShowButton()
lInfo->setText( i18n("Press <strong>Mail...</strong> to send selected documents") );
}
- mw->setMinimumSize( TQSize( lInfo->sizeHint().width(), mw->sizeHint().height()) );
- setMinimumSize( calculateSize( mw->minimumSize().width(), mw->sizeHint().height() ) );
+ mw->setMinimumSize( TQSize( lInfo->tqsizeHint().width(), mw->tqsizeHint().height()) );
+ setMinimumSize( calculateSize( mw->tqminimumSize().width(), mw->tqsizeHint().height() ) );
resize( width(), minimumHeight() );
}
#include "katemailfilesdialog.moc"
diff --git a/kate/app/katemain.cpp b/kate/app/katemain.cpp
index 371161de0..9ba62782a 100644
--- a/kate/app/katemain.cpp
+++ b/kate/app/katemain.cpp
@@ -253,4 +253,4 @@ extern "C" KDE_EXPORT int kdemain( int argc, char **argv )
return app.exec();
}
-// kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on; mixed-indent off;
diff --git a/kate/app/katemainwindow.cpp b/kate/app/katemainwindow.cpp
index dea2b0fae..331194159 100644
--- a/kate/app/katemainwindow.cpp
+++ b/kate/app/katemainwindow.cpp
@@ -101,7 +101,7 @@ KateMainWindow::KateMainWindow (KConfig *sconfig, const TQString &sgroup)
// here we go, set some usable default sizes
if (!initialGeometrySet())
{
- int scnum = TQApplication::desktop()->screenNumber(parentWidget());
+ int scnum = TQApplication::desktop()->screenNumber(tqparentWidget());
TQRect desk = TQApplication::desktop()->screenGeometry(scnum);
TQSize size;
@@ -110,8 +110,8 @@ KateMainWindow::KateMainWindow (KConfig *sconfig, const TQString &sgroup)
if (sconfig)
{
sconfig->setGroup (sgroup);
- size.setWidth (sconfig->readNumEntry( TQString::fromLatin1("Width %1").arg(desk.width()), 0 ));
- size.setHeight (sconfig->readNumEntry( TQString::fromLatin1("Height %1").arg(desk.height()), 0 ));
+ size.setWidth (sconfig->readNumEntry( TQString::tqfromLatin1("Width %1").arg(desk.width()), 0 ));
+ size.setHeight (sconfig->readNumEntry( TQString::tqfromLatin1("Height %1").arg(desk.height()), 0 ));
}
// if thats fails, try to reuse size
@@ -131,8 +131,8 @@ KateMainWindow::KateMainWindow (KConfig *sconfig, const TQString &sgroup)
{
// first try global app config
KateApp::self()->config()->setGroup ("MainWindow");
- size.setWidth (KateApp::self()->config()->readNumEntry( TQString::fromLatin1("Width %1").arg(desk.width()), 0 ));
- size.setHeight (KateApp::self()->config()->readNumEntry( TQString::fromLatin1("Height %1").arg(desk.height()), 0 ));
+ size.setWidth (KateApp::self()->config()->readNumEntry( TQString::tqfromLatin1("Width %1").arg(desk.width()), 0 ));
+ size.setHeight (KateApp::self()->config()->readNumEntry( TQString::tqfromLatin1("Height %1").arg(desk.height()), 0 ));
if (size.isEmpty())
size = TQSize (kMin (700, desk.width()), kMin(480, desk.height()));
@@ -851,4 +851,4 @@ void KateMainWindow::saveGlobalProperties( KConfig* sessionConfig )
sessionConfig->writeEntry ("Last Session", KateApp::self()->sessionManager()->activeSession()->sessionFileRelative());
}
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/katemainwindow.h b/kate/app/katemainwindow.h
index 77db9999c..e0859bcbd 100644
--- a/kate/app/katemainwindow.h
+++ b/kate/app/katemainwindow.h
@@ -213,4 +213,4 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
#endif
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/katemdi.cpp b/kate/app/katemdi.cpp
index 9d73e762c..64aef77bc 100644
--- a/kate/app/katemdi.cpp
+++ b/kate/app/katemdi.cpp
@@ -128,7 +128,7 @@ GUIClient::GUIClient ( MainWindow *mw )
if ( domDocument().documentElement().isNull() )
{
- TQString completeDescription = TQString::fromLatin1( guiDescription )
+ TQString completeDescription = TQString::tqfromLatin1( guiDescription )
.arg( actionListName );
setXML( completeDescription, false /*merge*/ );
@@ -339,7 +339,7 @@ ToolView *Sidebar::addWidget (const TQPixmap &icon, const TQString &text, ToolVi
bool Sidebar::removeWidget (ToolView *widget)
{
- if (!m_widgetToId.contains(widget))
+ if (!m_widgetToId.tqcontains(widget))
return false;
removeTab(m_widgetToId[widget]);
@@ -369,7 +369,7 @@ bool Sidebar::removeWidget (ToolView *widget)
bool Sidebar::showWidget (ToolView *widget)
{
- if (!m_widgetToId.contains(widget))
+ if (!m_widgetToId.tqcontains(widget))
return false;
// hide other non-persistent views
@@ -394,7 +394,7 @@ bool Sidebar::showWidget (ToolView *widget)
bool Sidebar::hideWidget (ToolView *widget)
{
- if (!m_widgetToId.contains(widget))
+ if (!m_widgetToId.tqcontains(widget))
return false;
bool anyVis = false;
@@ -579,7 +579,7 @@ void Sidebar::restoreSession (KConfig *config)
}
// then: remove this items from the button bar
- // do this backwards, to minimize the relayout efforts
+ // do this backwards, to minimize the retqlayout efforts
for (int i=m_toolviews.size()-1; i >= (int)firstWrong; --i)
{
removeTab (m_widgetToId[m_toolviews[i]]);
@@ -659,8 +659,8 @@ void Sidebar::saveSession (KConfig *config)
//BEGIN MAIN WINDOW
-MainWindow::MainWindow (TQWidget* parentWidget, const char* name)
- : KParts::MainWindow( parentWidget, name)
+MainWindow::MainWindow (TQWidget* tqparentWidget, const char* name)
+ : KParts::MainWindow( tqparentWidget, name)
, m_sidebarsVisible(true)
, m_restoreConfig (0)
, m_guiClient (new GUIClient (this))
diff --git a/kate/app/katemdi.h b/kate/app/katemdi.h
index 1b13c30a8..915589d77 100644
--- a/kate/app/katemdi.h
+++ b/kate/app/katemdi.h
@@ -258,7 +258,7 @@ class MainWindow : public KParts::MainWindow
/**
* Constructor
*/
- MainWindow (TQWidget* parentWidget = 0, const char* name = 0);
+ MainWindow (TQWidget* tqparentWidget = 0, const char* name = 0);
/**
* Destructor
diff --git a/kate/app/katemwmodonhddialog.cpp b/kate/app/katemwmodonhddialog.cpp
index 5199a6925..263d06c7e 100644
--- a/kate/app/katemwmodonhddialog.cpp
+++ b/kate/app/katemwmodonhddialog.cpp
@@ -91,7 +91,7 @@ KateMwModOnHdDialog::KateMwModOnHdDialog( DocVector docs, TQWidget *parent, cons
// document list
lvDocuments = new KListView( w );
lvDocuments->addColumn( i18n("Filename") );
- lvDocuments->addColumn( i18n("Status on Disk") );
+ lvDocuments->addColumn( i18n("tqStatus on Disk") );
lvDocuments->setSelectionMode( TQListView::Single );
TQStringList l;
@@ -278,4 +278,4 @@ void KateMwModOnHdDialog::slotPDone( KProcess *p )
m_tmpfile = 0;
}
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/katemwmodonhddialog.h b/kate/app/katemwmodonhddialog.h
index 7a5d8f7ca..121761f38 100644
--- a/kate/app/katemwmodonhddialog.h
+++ b/kate/app/katemwmodonhddialog.h
@@ -58,4 +58,4 @@ class KateMwModOnHdDialog : public KDialogBase
};
#endif // _KATE_MW_MODONHD_DIALOG_H_
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/katesession.cpp b/kate/app/katesession.cpp
index fd0e059f9..70c844804 100644
--- a/kate/app/katesession.cpp
+++ b/kate/app/katesession.cpp
@@ -917,4 +917,4 @@ void KateSessionsAction::openSession (int i)
KateSessionManager::self()->activateSession(slist[(uint)i]);
}
-// kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on; mixed-indent off;
diff --git a/kate/app/katetabwidget.cpp b/kate/app/katetabwidget.cpp
index 4b278e327..cd9df55d1 100644
--- a/kate/app/katetabwidget.cpp
+++ b/kate/app/katetabwidget.cpp
@@ -70,7 +70,7 @@ void KateTabWidget::insertTab ( TQWidget * child, const TQString & label, int in
KTabWidget::insertTab(child,label,index);
showPage(child);
maybeShow();
- tabBar()->repaint();
+ tabBar()->tqrepaint();
}
void KateTabWidget::insertTab ( TQWidget * child, const TQIconSet & iconset, const TQString & label, int index )
@@ -78,7 +78,7 @@ void KateTabWidget::insertTab ( TQWidget * child, const TQIconSet & iconset, con
KTabWidget::insertTab(child,iconset,label,index);
showPage(child);
maybeShow();
- tabBar()->repaint();
+ tabBar()->tqrepaint();
}
void KateTabWidget::insertTab ( TQWidget * child, TQTab * tab, int index)
@@ -86,7 +86,7 @@ void KateTabWidget::insertTab ( TQWidget * child, TQTab * tab, int index)
KTabWidget::insertTab(child,tab,index);
showPage(child);
maybeShow();
- tabBar()->repaint();
+ tabBar()->tqrepaint();
}
void KateTabWidget::removePage ( TQWidget * w )
diff --git a/kate/app/kateviewmanager.cpp b/kate/app/kateviewmanager.cpp
index c62e6e082..08f080fec 100644
--- a/kate/app/kateviewmanager.cpp
+++ b/kate/app/kateviewmanager.cpp
@@ -511,4 +511,4 @@ KateMainWindow *KateViewManager::mainWindow() {
return m_mainWindow;
}
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/kateviewspace.cpp b/kate/app/kateviewspace.cpp
index 43a73a2b6..de7090215 100644
--- a/kate/app/kateviewspace.cpp
+++ b/kate/app/kateviewspace.cpp
@@ -67,9 +67,9 @@ protected:
void paintEvent( TQPaintEvent *e )
{
TQPainter p( this );
- p.setPen( colorGroup().shadow() );
+ p.setPen( tqcolorGroup().shadow() );
p.drawLine( e->rect().left(), 0, e->rect().right(), 0 );
- p.setPen( ((KateViewSpace*)parentWidget())->isActiveSpace() ? colorGroup().light() : colorGroup().midlight() );
+ p.setPen( ((KateViewSpace*)tqparentWidget())->isActiveSpace() ? tqcolorGroup().light() : tqcolorGroup().midlight() );
p.drawLine( e->rect().left(), 1, e->rect().right(), 1 );
}
};
@@ -226,9 +226,9 @@ bool KateViewSpace::event( TQEvent *e )
return TQVBox::event( e );
}
-void KateViewSpace::slotStatusChanged (Kate::View *view, int r, int c, int ovr, bool block, int mod, const TQString &msg)
+void KateViewSpace::slottqStatusChanged (Kate::View *view, int r, int c, int ovr, bool block, int mod, const TQString &msg)
{
- if ((TQWidgetStack *)view->parentWidget() != stack)
+ if ((TQWidgetStack *)view->tqparentWidget() != stack)
return;
mStatusBar->setStatus( r, c, ovr, block, mod, msg );
}
@@ -309,29 +309,29 @@ KateVSStatusBar::KateVSStatusBar ( KateViewSpace *parent, const char *name )
{
m_lineColLabel = new TQLabel( this );
addWidget( m_lineColLabel, 0, false );
- m_lineColLabel->setAlignment( Qt::AlignCenter );
+ m_lineColLabel->tqsetAlignment( Qt::AlignCenter );
m_lineColLabel->installEventFilter( this );
m_modifiedLabel = new TQLabel( TQString(" "), this );
addWidget( m_modifiedLabel, 0, false );
- m_modifiedLabel->setAlignment( Qt::AlignCenter );
+ m_modifiedLabel->tqsetAlignment( Qt::AlignCenter );
m_modifiedLabel->installEventFilter( this );
m_insertModeLabel = new TQLabel( i18n(" INS "), this );
addWidget( m_insertModeLabel, 0, false );
- m_insertModeLabel->setAlignment( Qt::AlignCenter );
+ m_insertModeLabel->tqsetAlignment( Qt::AlignCenter );
m_insertModeLabel->installEventFilter( this );
m_selectModeLabel = new TQLabel( i18n(" NORM "), this );
addWidget( m_selectModeLabel, 0, false );
- m_selectModeLabel->setAlignment( Qt::AlignCenter );
+ m_selectModeLabel->tqsetAlignment( Qt::AlignCenter );
m_selectModeLabel->installEventFilter( this );
m_fileNameLabel=new KSqueezedTextLabel( this );
addWidget( m_fileNameLabel, 1, true );
m_fileNameLabel->setMinimumSize( 0, 0 );
- m_fileNameLabel->setSizePolicy(TQSizePolicy( TQSizePolicy::Ignored, TQSizePolicy::Fixed ));
- m_fileNameLabel->setAlignment( /*Qt::AlignRight*/Qt::AlignLeft );
+ m_fileNameLabel->tqsetSizePolicy(TQSizePolicy( TQSizePolicy::Ignored, TQSizePolicy::Fixed ));
+ m_fileNameLabel->tqsetAlignment( /*Qt::AlignRight*/Qt::AlignLeft );
m_fileNameLabel->installEventFilter( this );
installEventFilter( this );
@@ -396,7 +396,7 @@ void KateVSStatusBar::modifiedChanged()
void KateVSStatusBar::showMenu()
{
- KMainWindow* mainWindow = static_cast<KMainWindow*>( topLevelWidget() );
+ KMainWindow* mainWindow = static_cast<KMainWindow*>( tqtopLevelWidget() );
TQPopupMenu* menu = static_cast<TQPopupMenu*>( mainWindow->factory()->container("viewspace_popup", mainWindow ) );
if (menu)
@@ -419,4 +419,4 @@ bool KateVSStatusBar::eventFilter(TQObject*,TQEvent *e)
return false;
}
//END KateVSStatusBar
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/kateviewspace.h b/kate/app/kateviewspace.h
index b6a5a185e..9f1106aab 100644
--- a/kate/app/kateviewspace.h
+++ b/kate/app/kateviewspace.h
@@ -110,7 +110,7 @@ class KateViewSpace : public QVBox
TQString m_group;
private slots:
- void slotStatusChanged (Kate::View *view, int r, int c, int ovr, bool block, int mod, const TQString &msg);
+ void slottqStatusChanged (Kate::View *view, int r, int c, int ovr, bool block, int mod, const TQString &msg);
public slots:
void polish();
@@ -118,4 +118,4 @@ class KateViewSpace : public QVBox
};
#endif
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/kateviewspacecontainer.cpp b/kate/app/kateviewspacecontainer.cpp
index 1e05e8b5a..a441e3adb 100644
--- a/kate/app/kateviewspacecontainer.cpp
+++ b/kate/app/kateviewspacecontainer.cpp
@@ -69,7 +69,7 @@ KateViewSpaceContainer::KateViewSpaceContainer (TQWidget *parent, KateViewManage
m_viewSpaceList.setAutoDelete(true);
KateViewSpace* vs = new KateViewSpace( this, this );
- connect(this, TQT_SIGNAL(statusChanged(Kate::View *, int, int, int, bool, int, const TQString&)), vs, TQT_SLOT(slotStatusChanged(Kate::View *, int, int, int, bool, int, const TQString&)));
+ connect(this, TQT_SIGNAL(statusChanged(Kate::View *, int, int, int, bool, int, const TQString&)), vs, TQT_SLOT(slottqStatusChanged(Kate::View *, int, int, int, bool, int, const TQString&)));
vs->setActive( true );
m_viewSpaceList.append(vs);
connect( this, TQT_SIGNAL(viewChanged()), this, TQT_SLOT(slotViewChanged()) );
@@ -124,7 +124,7 @@ bool KateViewSpaceContainer::createView ( Kate::Document *doc )
connect(view->getDoc(),TQT_SIGNAL(nameChanged(Kate::Document *)),this,TQT_SLOT(statusMsg()));
connect(view,TQT_SIGNAL(cursorPositionChanged()),this,TQT_SLOT(statusMsg()));
- connect(view,TQT_SIGNAL(newStatus()),this,TQT_SLOT(statusMsg()));
+ connect(view,TQT_SIGNAL(newtqStatus()),this,TQT_SLOT(statusMsg()));
connect(view->getDoc(), TQT_SIGNAL(undoChanged()), this, TQT_SLOT(statusMsg()));
connect(view,TQT_SIGNAL(dropEventPass(TQDropEvent *)), mainWindow(),TQT_SLOT(slotDropEvent(TQDropEvent *)));
connect(view,TQT_SIGNAL(gotFocus(Kate::View *)),this,TQT_SLOT(activateSpace(Kate::View *)));
@@ -141,7 +141,7 @@ bool KateViewSpaceContainer::deleteView (Kate::View *view, bool delViewSpace)
{
if (!view) return true;
- KateViewSpace *viewspace = (KateViewSpace *)view->parentWidget()->parentWidget();
+ KateViewSpace *viewspace = (KateViewSpace *)view->tqparentWidget()->tqparentWidget();
viewspace->removeView (view);
@@ -241,7 +241,7 @@ void KateViewSpaceContainer::activateSpace (Kate::View* v)
{
if (!v) return;
- KateViewSpace* vs = (KateViewSpace*)v->parentWidget()->parentWidget();
+ KateViewSpace* vs = (KateViewSpace*)v->tqparentWidget()->tqparentWidget();
if (!vs->isActiveSpace()) {
setActiveSpace (vs);
@@ -446,23 +446,23 @@ void KateViewSpaceContainer::splitViewSpace( KateViewSpace* vs,
if (!activeView()) return;
if (!vs) vs = activeViewSpace();
- bool isFirstTime = vs->parentWidget() == this;
+ bool isFirstTime = vs->tqparentWidget() == this;
TQValueList<int> psizes;
if ( ! isFirstTime )
- if ( TQSplitter *ps = static_cast<TQSplitter*>(vs->parentWidget()->qt_cast("TQSplitter")) )
+ if ( TQSplitter *ps = static_cast<TQSplitter*>(vs->tqparentWidget()->qt_cast("TQSplitter")) )
psizes = ps->sizes();
Qt::Orientation o = isHoriz ? Qt::Vertical : Qt::Horizontal;
- KateMDI::Splitter* s = new KateMDI::Splitter(o, vs->parentWidget());
+ KateMDI::Splitter* s = new KateMDI::Splitter(o, vs->tqparentWidget());
s->setOpaqueResize( KGlobalSettings::opaqueResize() );
if (! isFirstTime) {
// anders: make sure the split' viewspace is always
// correctly positioned.
// If viewSpace is the first child, the new splitter must be moveToFirst'd
- if ( !((KateMDI::Splitter*)vs->parentWidget())->isLastChild( vs ) )
- ((KateMDI::Splitter*)s->parentWidget())->moveToFirst( s );
+ if ( !((KateMDI::Splitter*)vs->tqparentWidget())->isLastChild( vs ) )
+ ((KateMDI::Splitter*)s->tqparentWidget())->moveToFirst( s );
}
vs->reparent( s, 0, TQPoint(), true );
KateViewSpace* vsNew = new KateViewSpace( this, s );
@@ -471,17 +471,17 @@ void KateViewSpaceContainer::splitViewSpace( KateViewSpace* vs,
s->moveToFirst( vsNew );
if (!isFirstTime)
- if (TQSplitter *ps = static_cast<TQSplitter*>(s->parentWidget()->qt_cast("TQSplitter")) )
+ if (TQSplitter *ps = static_cast<TQSplitter*>(s->tqparentWidget()->qt_cast("TQSplitter")) )
ps->setSizes( psizes );
s->show();
TQValueList<int> sizes;
- int space = 50;//isHoriz ? s->parentWidget()->height()/2 : s->parentWidget()->width()/2;
+ int space = 50;//isHoriz ? s->tqparentWidget()->height()/2 : s->tqparentWidget()->width()/2;
sizes << space << space;
s->setSizes( sizes );
- connect(this, TQT_SIGNAL(statusChanged(Kate::View *, int, int, int, bool, int, const TQString &)), vsNew, TQT_SLOT(slotStatusChanged(Kate::View *, int, int,int, bool, int, const TQString &)));
+ connect(this, TQT_SIGNAL(statusChanged(Kate::View *, int, int, int, bool, int, const TQString &)), vsNew, TQT_SLOT(slottqStatusChanged(Kate::View *, int, int,int, bool, int, const TQString &)));
m_viewSpaceList.append( vsNew );
activeViewSpace()->setActive( false );
vsNew->setActive( true, true );
@@ -503,7 +503,7 @@ void KateViewSpaceContainer::removeViewSpace (KateViewSpace *viewspace)
// abort if this is the last viewspace
if (m_viewSpaceList.count() < 2) return;
- KateMDI::Splitter* p = (KateMDI::Splitter*)viewspace->parentWidget();
+ KateMDI::Splitter* p = (KateMDI::Splitter*)viewspace->tqparentWidget();
// find out if it is the first child for repositioning
// see below
@@ -512,9 +512,9 @@ void KateViewSpaceContainer::removeViewSpace (KateViewSpace *viewspace)
// save some size information
KateMDI::Splitter* pp=0L;
TQValueList<int> ppsizes;
- if (m_viewSpaceList.count() > 2 && p->parentWidget() != this)
+ if (m_viewSpaceList.count() > 2 && p->tqparentWidget() != this)
{
- pp = (KateMDI::Splitter*)p->parentWidget();
+ pp = (KateMDI::Splitter*)p->tqparentWidget();
ppsizes = pp->sizes();
pIsFirst = !pp->isLastChild( p ); // simple logic, right-
}
@@ -554,10 +554,10 @@ void KateViewSpaceContainer::removeViewSpace (KateViewSpace *viewspace)
{
TQWidget* other = ((TQWidget *)(( TQPtrList<TQObject>*)p->children())->first());
- other->reparent( p->parentWidget(), 0, TQPoint(), true );
+ other->reparent( p->tqparentWidget(), 0, TQPoint(), true );
// We also need to find the right viewspace to become active
if (pIsFirst)
- ((KateMDI::Splitter*)p->parentWidget())->moveToFirst( other );
+ ((KateMDI::Splitter*)p->tqparentWidget())->moveToFirst( other );
if ( other->isA("KateViewSpace") ) {
setActiveSpace( (KateViewSpace*)other );
}
@@ -726,7 +726,7 @@ void KateViewSpaceContainer::restoreSplitter( KConfig* config, const TQString &g
{
KateViewSpace* vs = new KateViewSpace( this, s );
- connect(this, TQT_SIGNAL(statusChanged(Kate::View *, int, int, int, bool, int, const TQString &)), vs, TQT_SLOT(slotStatusChanged(Kate::View *, int, int, int, bool, int, const TQString &)));
+ connect(this, TQT_SIGNAL(statusChanged(Kate::View *, int, int, int, bool, int, const TQString &)), vs, TQT_SLOT(slottqStatusChanged(Kate::View *, int, int, int, bool, int, const TQString &)));
if (m_viewSpaceList.isEmpty())
vs->setActive (true);
@@ -755,4 +755,4 @@ KateMainWindow *KateViewSpaceContainer::mainWindow() {
return m_viewManager->mainWindow();
}
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
diff --git a/kate/app/kwritemain.cpp b/kate/app/kwritemain.cpp
index efb71b767..2ac1e5d9e 100644
--- a/kate/app/kwritemain.cpp
+++ b/kate/app/kwritemain.cpp
@@ -96,8 +96,8 @@ KWrite::KWrite (KTextEditor::Document *doc)
setAcceptDrops(true);
- connect(m_view,TQT_SIGNAL(newStatus()),this,TQT_SLOT(newCaption()));
- connect(m_view,TQT_SIGNAL(viewStatusMsg(const TQString &)),this,TQT_SLOT(newStatus(const TQString &)));
+ connect(m_view,TQT_SIGNAL(newtqStatus()),this,TQT_SLOT(newCaption()));
+ connect(m_view,TQT_SIGNAL(viewtqStatusMsg(const TQString &)),this,TQT_SLOT(newtqStatus(const TQString &)));
connect(m_view->document(),TQT_SIGNAL(fileNameChanged()),this,TQT_SLOT(newCaption()));
connect(m_view->document(),TQT_SIGNAL(fileNameChanged()),this,TQT_SLOT(slotFileNameChanged()));
connect(m_view,TQT_SIGNAL(dropEventPass(TQDropEvent *)),this,TQT_SLOT(slotDropEvent(TQDropEvent *)));
@@ -112,7 +112,7 @@ KWrite::KWrite (KTextEditor::Document *doc)
// init with more usefull size, stolen from konq :)
if (!initialGeometrySet())
- resize( TQSize(700, 480).expandedTo(minimumSizeHint()));
+ resize( TQSize(700, 480).expandedTo(tqminimumSizeHint()));
// call it as last thing, must be sure everything is already set up ;)
setAutoSaveSettings ();
@@ -163,7 +163,7 @@ void KWrite::setupActions()
// setup Settings menu
setStandardToolBarMenuEnabled(true);
- m_paShowStatusBar = KStdAction::showStatusbar(this, TQT_SLOT(toggleStatusBar()), actionCollection(), "settings_show_statusbar");
+ m_paShowStatusBar = KStdAction::showtqStatusbar(this, TQT_SLOT(toggleStatusBar()), actionCollection(), "settings_show_statusbar");
m_paShowStatusBar->setWhatsThis(i18n("Use this command to show or hide the view's statusbar"));
m_paShowPath = new KToggleAction(i18n("Sho&w Path"), 0, this, TQT_SLOT(newCaption()),
@@ -320,7 +320,7 @@ void KWrite::printDlg()
KTextEditor::printInterface(m_view->document())->printDialog ();
}
-void KWrite::newStatus(const TQString &msg)
+void KWrite::newtqStatus(const TQString &msg)
{
newCaption();
@@ -709,4 +709,4 @@ void KWriteEditorChooser::slotOk() {
m_chooser->writeAppSetting();
KDialogBase::slotOk();
}
-// kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on; mixed-indent off;
diff --git a/kate/app/kwritemain.h b/kate/app/kwritemain.h
index 6a3565a6c..91c4240ff 100644
--- a/kate/app/kwritemain.h
+++ b/kate/app/kwritemain.h
@@ -76,7 +76,7 @@ class KWrite : public KParts::MainWindow
void printNow();
void printDlg();
- void newStatus(const TQString &msg);
+ void newtqStatus(const TQString &msg);
void newCaption();
void slotDropEvent(TQDropEvent *);
@@ -135,4 +135,4 @@ class KWriteEditorChooser: public KDialogBase
};
#endif
-// kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on; mixed-indent off;
diff --git a/kate/app/katefilelist.cpp b/kate/app/katefilelist.cpp
index 47c8aa75b..343f66a9a 100644
--- a/kate/app/katefilelist.cpp
+++ b/kate/app/katefilelist.cpp
@@ -69,7 +69,7 @@ class ToolTip : public QToolTip
KateFileListItem *item = ((KateFileListItem*)i);
if ( ! item ) return;
- tip( m_listView->itemRect( i ), m_listView->tooltip( item, 0 ) );
+ tip( m_listView->tqitemRect( i ), m_listView->tooltip( item, 0 ) );
}
@@ -273,11 +273,11 @@ void KateFileList::slotModChanged (Kate::Document *doc)
for ( uint i=0; i < m_editHistory.count(); i++ )
{
m_editHistory.at( i )->setEditHistPos( i+1 );
- repaintItem( m_editHistory.at( i ) );
+ tqrepaintItem( m_editHistory.at( i ) );
}
}
else
- repaintItem( item );
+ tqrepaintItem( item );
}
void KateFileList::slotModifiedOnDisc (Kate::Document *doc, bool, unsigned char)
@@ -296,7 +296,7 @@ void KateFileList::slotNameChanged (Kate::Document *doc)
if ( ((KateFileListItem*)item)->document() == doc )
{
item->setText( 0, doc->docName() );
- repaintItem( item );
+ tqrepaintItem( item );
break;
}
item = item->nextSibling();
@@ -334,7 +334,7 @@ void KateFileList::slotViewChanged ()
// int p = 0;
// if ( m_viewHistory.count() )
// {
// int p = m_viewHistory.findRef( item ); // only repaint items that needs it
// }
m_viewHistory.removeRef( item );
@@ -343,7 +343,7 @@ void KateFileList::slotViewChanged ()
for ( uint i=0; i < m_viewHistory.count(); i++ )
{
m_viewHistory.at( i )->setViewHistPos( i+1 );
- repaintItem( m_viewHistory.at( i ) );
+ tqrepaintItem( m_viewHistory.at( i ) );
}
}
@@ -475,7 +475,7 @@ void KateFileListItem::paintCell( TQPainter *painter, const TQColorGroup & cg, i
{
TQColorGroup cgNew = cg;
- // replace the base color with a different shading if necessary...
+ // tqreplace the base color with a different shading if necessary...
if ( fl->shadingEnabled() && m_viewhistpos > 1 )
{
TQColor b( cg.base() );
@@ -616,7 +616,7 @@ void KFLConfigPage::apply()
m_filelist->m_editShade = kcbEditShade->color();
m_filelist->m_enableBgShading = cbEnableShading->isChecked();
m_filelist->setSortType( cmbSort->currentItem() );
// repaint the affected items
m_filelist->triggerUpdate();
}
@@ -649,4 +649,4 @@ void KFLConfigPage::slotMyChanged()
//END KFLConfigPage
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 2; tqreplace-tabs on;
@@ -334,7 +334,7 @@ void KateFileList::slotViewChanged ()
// if ( m_viewHistory.count() )
// {
-// int p = m_viewHistory.findRef( item ); // only repaint items that needs it
+// int p = m_viewHistory.findRef( item ); // only tqrepaint items that needs it
// }
m_viewHistory.removeRef( item );
@@ -616,7 +616,7 @@ void KFLConfigPage::apply()
m_filelist->m_enableBgShading = cbEnableShading->isChecked();
m_filelist->setSortType( cmbSort->currentItem() );
- // repaint the affected items
+ // tqrepaint the affected items
m_filelist->triggerUpdate();
}